==> 1.1.0.tar.gz: lib/websocket_manager.dart <==
part of websocket_messaging;

class WebsocketManager{
  List<WebsocketListener> listeners = new List<WebsocketListener>();
  WebSocket ws;
  String server;
  
  static WebsocketManager instance;
  factory WebsocketManager(String url,void outputMsg(string)){
    if(instance == null){
      instance = new WebsocketManager._internal(url,outputMsg);
    }
    return instance;
  }
  
  WebsocketManager._internal(String url,void outputMsg(string)){
    void initWebSocket([int retrySeconds = 2]) {
      outputMsg("initWebSocket");
        var encounteredError = false;
        
        outputMsg("Connecting to Web socket");
        ws = new WebSocket(url);
        
        ws.onOpen.listen((e) {
          listeners.forEach((WebsocketListener listener){
            listener.onOpen(e);
          });
          ws.send('Hello from Dart!');
        });
        
        ws.onClose.listen((e) {
          listeners.forEach((WebsocketListener listener){
            listener.onClose(e);
          });
          if (!encounteredError) {
            new Timer(new Duration(seconds:retrySeconds),
                () => initWebSocket(retrySeconds*2));
          } 
          encounteredError = true;
        });
        
        ws.onError.listen((e) {
          listeners.forEach((WebsocketListener listener){
            listener.onError(e);
          });
          if (!encounteredError) {
            new Timer(new Duration(seconds:retrySeconds),
                () => initWebSocket(retrySeconds*2));
          } 
          encounteredError = true;
        });
        
        ws.onMessage.listen((MessageEvent e) {
          listeners.forEach((WebsocketListener listener){
            listener.onMessage(e);
          });
        });
    }
  }
  
  void addListener(WebsocketListener listener){
    listeners.add(listener);
  }
  void sendText(String textToSend){
    ws.sendString(textToSend);
  }
}

==> 2.0.1.tar.gz: lib/websocket_manager.dart <==
part of websocket_messaging;

class WebsocketManager{
  List<WebsocketListener> listeners = new List<WebsocketListener>();
  WebSocket ws;
  String server;
  static WebsocketManager instance;
  
  factory WebsocketManager(String url,void outputMsg(string)){
    if(instance == null){
      instance = new WebsocketManager._internal(url,outputMsg);
    }
    return instance;
  }
  
  WebsocketManager._internal(String url,void outputMsg(string)){
    initWebSocket(url, outputMsg);
  }
    void initWebSocket(String url,void outputMsg(string),[int retrySeconds = 2]) {
      outputMsg("initWebSocket");
        var encounteredError = false;
        
        outputMsg("Connecting to Web socket");
        ws = new WebSocket(url);
        
        ws.onOpen.listen((e) {
          listeners.forEach((WebsocketListener listener){
            listener.onOpen(e);
          });
          ws.send('Hello from Dart!');
        });
        
        ws.onClose.listen((e) {
          listeners.forEach((WebsocketListener listener){
            listener.onClose(e);
          });
          if (!encounteredError) {
            new Timer(new Duration(seconds:retrySeconds),
                () => initWebSocket(url,outputMsg,retrySeconds*2));
          } 
          encounteredError = true;
        });
        
        ws.onError.listen((e) {
          listeners.forEach((WebsocketListener listener){
            listener.onError(e);
          });
          if (!encounteredError) {
            new Timer(new Duration(seconds:retrySeconds),
                () => initWebSocket(url,outputMsg,retrySeconds*2));
          } 
          encounteredError = true;
        });
        
        ws.onMessage.listen((MessageEvent e) {
          listeners.forEach((WebsocketListener listener){
            listener.onMessage(e);
          });
        });
    }
  void addListener(WebsocketListener listener){
    listeners.add(listener);
  }
  void sendText(String textToSend,[int retrySeconds = 2]){
    print(ws.readyState);
    if(ws.readyState==0){
      new Timer(new Duration(seconds:retrySeconds),
                () => sendText(textToSend,retrySeconds*2)); 
    }
    else{
      ws.sendString(textToSend);
    }
  }
}
